/* mvme - Mesytec VME Data Acquisition
 *
 * Copyright (C) 2016-2020 mesytec GmbH & Co. KG <info@mesytec.com>
 *
 * Author: Florian Lüke <f.lueke@mesytec.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
#ifndef __MVME_LISTFILE_READER_LISTFILE_READER_H__
#define __MVME_LISTFILE_READER_LISTFILE_READER_H__

#include <stdint.h>

extern "C"
{

struct ModuleReadoutDescription
{
    const char *name;
    const char *type;
    unsigned prefixLen;
    unsigned suffixLen;
    bool hasDynamic;
};

struct EventReadoutDescription
{
    const char *name;
    ModuleReadoutDescription *modules;
    int moduleCount;
};

struct RunDescription
{
    const char *listfileFilename;
    EventReadoutDescription *events;
    int eventCount;
};

struct DataBlock
{
    const uint32_t *data;
    uint32_t size;
};

struct ModuleData
{
    DataBlock prefix;
    DataBlock dynamic;
    DataBlock suffix;
};

typedef void (*PluginInfo) (char **pluginName, char **pluginDescription);
typedef void * (*PluginInit) (const char *pluginFilename, int argc, const char *argv[]);
typedef void (*PluginDestroy) (void *userptr);

typedef void (*BeginRun) (void *userptr, const RunDescription *run);
typedef void (*EventData) (void *userptr, int eventIndex, const ModuleData *modules, int moduleCount);
typedef void (*EndRun) (void *userptr);

}

#endif /* __MVME_LISTFILE_READER_LISTFILE_READER_H__ */
